% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/quicksight_operations.R
\name{quicksight_update_template}
\alias{quicksight_update_template}
\title{Updates a template from an existing Amazon QuickSight analysis or
another template}
\usage{
quicksight_update_template(AwsAccountId, TemplateId, SourceEntity,
  VersionDescription, Name)
}
\arguments{
\item{AwsAccountId}{[required] The ID of the AWS account that contains the template that you're
updating.}

\item{TemplateId}{[required] The ID for the template.}

\item{SourceEntity}{[required] The entity that you are using as a source when you update the template.
In \code{SourceEntity}, you specify the type of object you're using as
source: \code{SourceTemplate} for a template or \code{SourceAnalysis} for an
analysis. Both of these require an Amazon Resource Name (ARN). For
\code{SourceTemplate}, specify the ARN of the source template. For
\code{SourceAnalysis}, specify the ARN of the source analysis. The
\code{SourceTemplate} ARN can contain any AWS Account and any
QuickSight-supported AWS Region.

Use the \code{DataSetReferences} entity within \code{SourceTemplate} or
\code{SourceAnalysis} to list the replacement datasets for the placeholders
listed in the original. The schema in each dataset must match its
placeholder.}

\item{VersionDescription}{A description of the current template version that is being updated.
Every time you call \code{\link[=quicksight_update_template]{update_template}}, you
create a new version of the template. Each version of the template
maintains a description of the version in the \code{VersionDescription}
field.}

\item{Name}{The name for the template.}
}
\value{
A list with the following syntax:\preformatted{list(
  TemplateId = "string",
  Arn = "string",
  VersionArn = "string",
  CreationStatus = "CREATION_IN_PROGRESS"|"CREATION_SUCCESSFUL"|"CREATION_FAILED"|"UPDATE_IN_PROGRESS"|"UPDATE_SUCCESSFUL"|"UPDATE_FAILED"|"DELETED",
  Status = 123,
  RequestId = "string"
)
}
}
\description{
Updates a template from an existing Amazon QuickSight analysis or
another template.
}
\section{Request syntax}{
\preformatted{svc$update_template(
  AwsAccountId = "string",
  TemplateId = "string",
  SourceEntity = list(
    SourceAnalysis = list(
      Arn = "string",
      DataSetReferences = list(
        list(
          DataSetPlaceholder = "string",
          DataSetArn = "string"
        )
      )
    ),
    SourceTemplate = list(
      Arn = "string"
    )
  ),
  VersionDescription = "string",
  Name = "string"
)
}
}

\keyword{internal}
